@@ -16,6 +16,7 @@ class ActionParser(Parser):
 	results: List[ParserResponse]
 
 	def __init__(self, results: dict, url: str):
+		super().__init__(results=results, url=url)
 		ActionParser.results.append(ActionParser.parse_response(results, url))
 
 	@staticmethod
@@ -50,6 +51,6 @@ class ActionParser(Parser):
 				action_detail = f"{object_id} completed successfully: {success_report}"
 
 				logger.info(f"The requested job is {job_status}")
-				logger.error(f"Failure Dump Available: {failure_dump}, Successful: {success_report}")
+				logger.info(f"Failure Dump Available: {failure_dump}, Successful: {success_report}")
 
 				return ParserResponse(action_detail, "", failure_dump, edf)
